/*
 *   (C) Copyright IBM Corp. 2001, 2003
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or 
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software 
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * Module: AIX Region Manager
 * File: evms2/engine/plugins/aix/aix_options.h
 *
 * Definitions of the options available in AIX.
 */ 

// Container creation options.
#define	AIX_OPTION_CONTAINER_PP_SIZE_INDEX	0
#define	AIX_OPTION_CONTAINER_PP_SIZE_STR	"pp_size"

// Region creation options
#define AIX_OPTION_REGION_NAME_INDEX		0
#define AIX_OPTION_REGION_NAME_STR		"name"
#define AIX_OPTION_REGION_NUM_LPS_INDEX		1
#define AIX_OPTION_REGION_NUM_LPS_STR		"num_pps"

#define AIX_OPTION_REGION_EXPAND_SIZE_INDEX 0
#define AIX_OPTION_REGION_EXPAND_SIZE_STR   "size"

// Container creation function prototypes.
extern int aix_create_container_parse_options(	option_array_t	* options,
						unsigned long	* pp_size );
extern int aix_create_container_verify_options( unsigned long	* pp_size );
extern int aix_create_container_allocate_option_descriptor( option_desc_array_t * od );
extern int aix_create_container_get_acceptable( dlist_t acceptable_segments );
extern int aix_create_container_set_objects(	task_context_t	* context,
						dlist_t		declined_objects,
						task_effect_t	* effect );
extern int aix_create_container_set_option(	task_context_t	* context,
						u_int32_t	index,
						value_t		* value,
						task_effect_t	* effect );

// Region creation function prototypes.
extern int aix_create_region_parse_options(	option_array_t		* options,
						aix_region_options_t	* region_opts );
extern int aix_create_region_verify_options( aix_region_options_t * region_opts );
extern int aix_create_region_allocate_option_descriptor( option_desc_array_t * od );
extern int aix_create_region_get_acceptable( dlist_t acceptable_segments );
extern int aix_create_region_set_objects(	task_context_t	* context,
						dlist_t		declined_objects,
						task_effect_t	* effect );
extern int aix_create_region_set_option(	task_context_t	* context,
						u_int32_t	index,
						value_t		* value,
						task_effect_t	* effect );
extern int aix_expand_region_parse_options(option_array_t   * options,
                                    storage_object_t        * region,
			                    	aix_region_options_t	* region_opts );
extern int aix_expand_region_verify_options( aix_region_options_t * region_opts,
                                                 storage_object_t * region);
extern int aix_shrink_region_parse_options(option_array_t		    * options,
                                    storage_object_t    * region,
			                    	aix_region_options_t	* region_opts );
extern int aix_shrink_region_verify_options( aix_region_options_t * region_opts,
                                      storage_object_t * region);
extern int aix_expand_container_allocate_option_descriptor( option_desc_array_t * od );
extern int aix_expand_container_get_acceptable( storage_container_t * container,
                                                dlist_t               acceptable_objects );
extern int aix_expand_region_allocate_option_descriptor( option_desc_array_t * od );
extern int aix_expand_region_get_acceptable( storage_object_t    * region,
                                             dlist_t               acceptable_objects );
extern int aix_shrink_region_allocate_option_descriptor( option_desc_array_t * od );
extern int aix_shrink_region_get_acceptable( storage_object_t    * region,
                                             dlist_t               acceptable_objects );
extern int aix_expand_region_set_objects(	task_context_t	* context,
					dlist_t		declined_objects,
					task_effect_t	* effect );
extern int aix_expand_container_set_objects(	task_context_t	* context,
					dlist_t		declined_objects,
					task_effect_t	* effect );
extern int aix_expand_container_set_option(	task_context_t	* context,
					u_int32_t	index,
					value_t		* value,
					task_effect_t	* effect );
extern int aix_expand_region_set_option(	task_context_t	* context,
					u_int32_t	index,
					value_t		* value,
					task_effect_t	* effect );
extern int aix_expand_container_parse_options(	option_array_t	* options,
					unsigned long	* pp_size );
extern int aix_list_acceptable_mirrors(storage_object_t *master_object,
                                       dlist_t          available_objects);
extern int aix_split_region_set_option(	task_context_t	* context,
					u_int32_t	index,
					value_t		* value,
					task_effect_t	* effect );
extern int aix_split_region_allocate_option_descriptor( option_desc_array_t * od );
extern int aix_get_available_objects(storage_object_t *region, int * count);
extern int aix_shrink_region_set_option(	task_context_t	* context,
					u_int32_t	index,
					value_t		* value,
					task_effect_t	* effect );
extern int aix_shrink_region_set_objects(	task_context_t	* context,
					dlist_t		declined_objects,
					task_effect_t	* effect );
